=======
History
=======

0.3.0 (2021-11-18)
------------------
* Added aggretation/window functions
* Added GROUP BY clause
* Added SELECT DISTINCT modifier
* Added SELECT PARTIALS modifier for running analytical/window queries

0.2.0 (2021-10-23)
------------------

* Added IMPORT clause
* Added ORDER BY clause
* Added support for init file

0.1.0 (2021-08-19)
------------------

* First release on PyPI.
